[llvm-commits] CVS: llvm/include/llvm/Target/TargetMachineImpls.h

Chris Lattner lattner at cs.uiuc.edu
Sun Dec 28 03:49:04 PST 2003


Changes in directory llvm/include/llvm/Target:

TargetMachineImpls.h updated: 1.7 -> 1.8

---
Log message:

We may now pass IntrinsicLowering implementations into these methods



---
Diffs of the changes:  (+19 -15)

Index: llvm/include/llvm/Target/TargetMachineImpls.h
diff -u llvm/include/llvm/Target/TargetMachineImpls.h:1.7 llvm/include/llvm/Target/TargetMachineImpls.h:1.8
--- llvm/include/llvm/Target/TargetMachineImpls.h:1.7	Tue Nov 11 16:41:31 2003
+++ llvm/include/llvm/Target/TargetMachineImpls.h	Sun Dec 28 03:48:17 2003
@@ -17,21 +17,25 @@
 
 namespace llvm {
 
-class TargetMachine;
-class Module;
-
-// allocateSparcTargetMachine - Allocate and return a subclass of TargetMachine
-// that implements the Sparc backend.
-//
-TargetMachine *allocateSparcTargetMachine(const Module &M);
-
-// allocateX86TargetMachine - Allocate and return a subclass of TargetMachine
-// that implements the X86 backend.  The X86 target machine can run in
-// "emulation" mode, where it is capable of emulating machines of larger pointer
-// size and different endianness if desired.
-//
-TargetMachine *allocateX86TargetMachine(const Module &M);
-
+  class TargetMachine;
+  class Module;
+  class IntrinsicLowering;
+  
+  // allocateSparcTargetMachine - Allocate and return a subclass of
+  // TargetMachine that implements the Sparc backend.  This takes ownership of
+  // the IntrinsicLowering pointer, deleting it when the target machine is
+  // destroyed.
+  //
+  TargetMachine *allocateSparcTargetMachine(const Module &M,
+                                            IntrinsicLowering *IL = 0);
+  
+  // allocateX86TargetMachine - Allocate and return a subclass of TargetMachine
+  // that implements the X86 backend.  This takes ownership of the
+  // IntrinsicLowering pointer, deleting it when the target machine is
+  // destroyed.
+  //
+  TargetMachine *allocateX86TargetMachine(const Module &M,
+                                          IntrinsicLowering *IL = 0);
 } // End llvm namespace
 
 #endif





More information about the llvm-commits mailing list